@@ -2,9 +2,9 @@ from __future__ import annotations
 
 from typing import List
 
-from async_search_client import Client
-from async_search_client.models import IndexBase, IndexInfo, IndexStats, UpdateId
 from fastapi import APIRouter, Depends, HTTPException
+from meilisearch_python_async import Client
+from meilisearch_python_async.models import IndexBase, IndexInfo, IndexStats, UpdateId
 
 from meilisearch_fastapi._config import MeiliSearchConfig, get_config
 from meilisearch_fastapi.models.index import (
@@ -33,7 +33,7 @@ router = APIRouter()
 async def create_index(
     index_info: IndexBase, config: MeiliSearchConfig = Depends(get_config)
 ) -> IndexInfo:
-    async with Client(config.url, api_key=config.api_key) as client:
+    async with Client(config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = await client.create_index(index_info.uid, index_info.primary_key)
 
         return IndexInfo(
@@ -49,7 +49,7 @@ async def delete_attributes_for_faceting(
     uid: str,
     config: MeiliSearchConfig = Depends(get_config),
 ) -> UpdateId:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
 
         return await index.reset_attributes_for_faceting()
@@ -59,7 +59,7 @@ async def delete_attributes_for_faceting(
 async def delete_displayed_attributes(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
 
         return await index.reset_displayed_attributes()
@@ -69,15 +69,23 @@ async def delete_displayed_attributes(
 async def delete_distinct_attribute(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
 
         return await index.reset_distinct_attribute()
 
 
+@router.delete("/delete-if-exists/{uid}", status_code=204)
+async def delete_if_exists(uid: str, config: MeiliSearchConfig = Depends(get_config)) -> int:
+    async with Client(config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
+        index = client.index(uid)
+        await index.delete_if_exists()
+        return 204
+
+
 @router.delete("/{uid}", status_code=204)
 async def delete_index(uid: str, config: MeiliSearchConfig = Depends(get_config)) -> int:
-    async with Client(config.url, api_key=config.api_key) as client:
+    async with Client(config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
         return await index.delete()
 
@@ -86,7 +94,7 @@ async def delete_index(uid: str, config: MeiliSearchConfig = Depends(get_config)
 async def delete_ranking_rules(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
 
         return await index.reset_ranking_rules()
@@ -96,7 +104,7 @@ async def delete_ranking_rules(
 async def delete_searchable_attributes(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
 
         return await index.reset_searchable_attributes()
@@ -104,7 +112,7 @@ async def delete_searchable_attributes(
 
 @router.delete("/stop-words/{uid}", response_model=UpdateId, status_code=202)
 async def delete_stop_words(uid: str, config: MeiliSearchConfig = Depends(get_config)) -> UpdateId:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
 
         return await index.reset_stop_words()
@@ -112,7 +120,7 @@ async def delete_stop_words(uid: str, config: MeiliSearchConfig = Depends(get_co
 
 @router.delete("/synonyms/{uid}", response_model=UpdateId, status_code=202)
 async def delete_synonyms(uid: str, config: MeiliSearchConfig = Depends(get_config)) -> UpdateId:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
 
         return await index.reset_synonyms()
@@ -123,7 +131,7 @@ async def get_attributes_for_faceting(
     uid: str,
     config: MeiliSearchConfig = Depends(get_config),
 ) -> AttributesForFaceting:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
         attributes_for_faceting = await index.get_attributes_for_faceting()
 
@@ -134,7 +142,7 @@ async def get_attributes_for_faceting(
 async def get_displayed_attributes(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> DisplayedAttributes:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
         displayed_attributes = await index.get_displayed_attributes()
 
@@ -145,7 +153,7 @@ async def get_displayed_attributes(
 async def get_distinct_attribute(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> DistinctAttribute:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
         attribute = await index.get_distinct_attribute()
 
@@ -157,7 +165,7 @@ async def get_index(
     uid: str,
     config: MeiliSearchConfig = Depends(get_config),
 ) -> IndexInfo:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = await client.get_raw_index(uid)
 
         if not index:
@@ -170,7 +178,7 @@ async def get_index(
 async def get_ranking_rules(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> RankingRules:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
         ranking_rules = await index.get_ranking_rules()
 
@@ -179,7 +187,7 @@ async def get_ranking_rules(
 
 @router.get("/stats/{uid}", response_model=IndexStats)
 async def get_stats(uid: str, config: MeiliSearchConfig = Depends(get_config)) -> IndexStats:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
 
         return await index.get_stats()
@@ -189,7 +197,7 @@ async def get_stats(uid: str, config: MeiliSearchConfig = Depends(get_config)) -
 async def get_indexes(
     config: MeiliSearchConfig = Depends(get_config),
 ) -> list[IndexInfo]:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         indexes = await client.get_raw_indexes()
 
         if not indexes:
@@ -200,7 +208,7 @@ async def get_indexes(
 
 @router.get("/primary-key/{uid}", response_model=PrimaryKey)
 async def get_primary_key(uid: str, config: MeiliSearchConfig = Depends(get_config)) -> PrimaryKey:
-    async with Client(config.url, api_key=config.api_key) as client:
+    async with Client(config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
         primary_key = await index.get_primary_key()
 
@@ -211,7 +219,7 @@ async def get_primary_key(uid: str, config: MeiliSearchConfig = Depends(get_conf
 async def get_searchable_attributes(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> SearchableAttributes:
-    async with Client(config.url, api_key=config.api_key) as client:
+    async with Client(config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
         attributes = await index.get_searchable_attributes()
 
@@ -220,7 +228,7 @@ async def get_searchable_attributes(
 
 @router.get("/stop-words/{uid}", response_model=StopWords)
 async def get_stop_words(uid: str, config: MeiliSearchConfig = Depends(get_config)) -> StopWords:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
         stop_words = await index.get_stop_words()
 
@@ -229,7 +237,7 @@ async def get_stop_words(uid: str, config: MeiliSearchConfig = Depends(get_confi
 
 @router.get("/synonyms/{uid}", response_model=Synonyms)
 async def get_synonyms(uid: str, config: MeiliSearchConfig = Depends(get_config)) -> Synonyms:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
         synonyms = await index.get_synonyms()
 
@@ -241,7 +249,7 @@ async def update_attributes_for_faceting(
     attributes_for_faceting: AttribugtesForFacetingWithUID,
     config: MeiliSearchConfig = Depends(get_config),
 ) -> UpdateId:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(attributes_for_faceting.uid)
         attributes = attributes_for_faceting.attributes_for_faceting or []
 
@@ -252,7 +260,7 @@ async def update_attributes_for_faceting(
 async def update_displayed_attributes(
     displayed_attributes: DisplayedAttributesUID, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(displayed_attributes.uid)
 
         return await index.update_displayed_attributes(displayed_attributes.displayed_attributes)
@@ -262,7 +270,7 @@ async def update_displayed_attributes(
 async def update_distinct_attribute(
     attribute_with_uid: DistinctAttributeWithUID, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
-    async with Client(config.url, api_key=config.api_key) as client:
+    async with Client(config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(attribute_with_uid.uid)
 
         return await index.update_distinct_attribute(attribute_with_uid.attribute)
@@ -272,12 +280,12 @@ async def update_distinct_attribute(
 async def update_index(
     index_update: IndexUpdate, config: MeiliSearchConfig = Depends(get_config)
 ) -> IndexInfo:
-    async with Client(config.url, api_key=config.api_key) as client:
+    async with Client(config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         payload = {}
         if index_update.primary_key is not None:
             payload["primaryKey"] = index_update.primary_key
         response = await client._http_requests.put(
-            f"{config.url}/indexes/{index_update.uid}", payload
+            f"{config.meilisearch_url}/indexes/{index_update.uid}", payload
         )
 
         return IndexInfo(**response.json())
@@ -287,7 +295,7 @@ async def update_index(
 async def update_ranking_rules(
     ranking_rules: RankingRulesWithUID, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(ranking_rules.uid)
 
         return await index.update_ranking_rules(ranking_rules.ranking_rules)
@@ -298,7 +306,7 @@ async def update_searchable_attributes(
     searchable_attributes: SearchableAttributesWithUID,
     config: MeiliSearchConfig = Depends(get_config),
 ) -> UpdateId:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(searchable_attributes.uid)
 
         return await index.update_searchable_attributes(searchable_attributes.searchable_attributes)
@@ -308,7 +316,7 @@ async def update_searchable_attributes(
 async def update_stop_words(
     stop_words: StopWordsWithUID, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(stop_words.uid)
         words = stop_words.stop_words or []
 
@@ -319,7 +327,7 @@ async def update_stop_words(
 async def update_synonyms(
     synonyms: SynonymsWithUID, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(synonyms.uid)
 
         if not synonyms.synonyms:
